#
# spec file for package seccheck
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           seccheck
Version:        3.0
Release:        18.14
Summary:        Security-Check Scripts
License:        GPL-2.0-or-later
Group:          Productivity/Security
URL:            https://github.com/openSUSE/seccheck
Source0:        https://github.com/openSUSE/seccheck/archive/master.zip
Source1:        sysconfig.seccheck
Patch1:         mail_headerlines_985802.patch
Patch2:         timers_wanted_by_1132919.patch
Patch3:         libexec_move_1178617.patch
Patch4:         security_announce_url_1178617.patch
BuildRequires:  unzip
Requires:       bash
# FIXME: use proper Requires(pre/post/preun/...)
PreReq:         %fillup_prereq
Provides:       suse-security-check-3.0
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

# Standard systemd requirements
BuildRequires:  pkgconfig(systemd)
%{?systemd_requires}

%description
Regularly executable scripts (via systemd timers) for checking the security of
your system. The seccheck systemd timers have to be enabled (and possibly started)
by the administrator for the checks to be run.

%prep
%setup -q -n seccheck-master
%autopatch -p1

%build

%install
install -d -m 700 %{buildroot}%{_localstatedir}/lib/secchk
install -d -m 700 %{buildroot}%{_localstatedir}/lib/secchk/data
install -d -m 750 %{buildroot}%{_libexecdir}/secchk
install -d -m 755 %{buildroot}%{_libexecdir}/secchk/blurbs
install -d -m 755 %{buildroot}%{_prefix}/doc/packages/secchk
install -d -m 755 %{buildroot}%{_sysconfdir}/cron.d
install -D -m 0644 %{name}-daily.service %{buildroot}%{_unitdir}/%{name}-daily.service
install -D -m 0644 %{name}-daily.timer %{buildroot}%{_unitdir}/%{name}-daily.timer
install -D -m 0644 %{name}-weekly.service %{buildroot}%{_unitdir}/%{name}-weekly.service
install -D -m 0644 %{name}-weekly.timer %{buildroot}%{_unitdir}/%{name}-weekly.timer
install -D -m 0644 %{name}-monthly.service %{buildroot}%{_unitdir}/%{name}-monthly.service
install -D -m 0644 %{name}-monthly.timer %{buildroot}%{_unitdir}/%{name}-monthly.timer
install -D -m 0644 %{name}-autologout.service %{buildroot}%{_unitdir}/%{name}-autologout.service
install -D -m 0644 %{name}-autologout.timer %{buildroot}%{_unitdir}/%{name}-autologout.timer
install -m 740 *.sh %{buildroot}%{_libexecdir}/secchk/
install -m 640 *.inc %{buildroot}%{_libexecdir}/secchk/
install -m 640 blurbs/*.txt %{buildroot}%{_libexecdir}/secchk/blurbs
install -m 740 checkneverlogin %{buildroot}%{_libexecdir}/secchk/
install -d %{buildroot}%{_fillupdir}
install -m 644 %{SOURCE1} %{buildroot}%{_fillupdir}/
install -d -m 755 %{buildroot}%{_sysconfdir}/security
install -m 644 autologout.conf %{buildroot}%{_sysconfdir}/security/

%pre
%service_add_pre seccheck-daily.timer seccheck-weekly.timer seccheck-monthly.timer

%post
%fillup_only
%service_add_post %{name}-daily.timer %{name}-weekly.timer %{name}-monthly.timer

%preun
%service_del_preun %{name}-daily.timer %{name}-weekly.timer %{name}-monthly.timer

%postun
%service_del_postun %{name}-daily.timer %{name}-weekly.timer %{name}-monthly.timer

%files
%defattr(-,root,root)
%doc TODO CHANGES README LICENCE
%{_libexecdir}/secchk
%{_unitdir}/%{name}-daily.service
%{_unitdir}/%{name}-daily.timer
%{_unitdir}/%{name}-weekly.service
%{_unitdir}/%{name}-weekly.timer
%{_unitdir}/%{name}-monthly.service
%{_unitdir}/%{name}-monthly.timer
%{_unitdir}/%{name}-autologout.service
%{_unitdir}/%{name}-autologout.timer
%dir %{_localstatedir}/lib/secchk
%dir %{_localstatedir}/lib/secchk/data
%{_fillupdir}/sysconfig.seccheck
%config %{_sysconfdir}/security/autologout.conf

%changelog
* Sun Dec 13 2020 <d_werner@gmx.net>
- libexec_move_1178617.patch: update paths after move to /usr/libexec
- security_announce_url_1178617.patch: update url for security
  announcements to suse (boo#1178617)
* Sun Dec 29 2019 d_werner@gmx.net
- update package description: no longer started by cron
* Sun Sep  8 2019 d_werner@gmx.net
- adapt WantedBy so the timers are actually started at boot
  time when enabled (#1132919)
  added patch: timers_wanted_by_1132919.patch
- correct indentation of SECCHK_FROM (#985802) for the
  weekly and monthly mails so that the mail header lines
  are recognised by the receiving mail client
  added patch: mail_headerlines_985802.patch
* Sat Mar 16 2019 Jan Engelhardt <jengelh@inai.de>
- Combine %%service_* calls to reduce generated boilerplate.
* Thu Mar  7 2019 abergmann@suse.com
- Move seccheck to systemd timers (bsc#1115415).
* Mon May  7 2018 vpereira@microfocus.com
- fixes proposed by the bsc#1084449:
  + introduction of SECCHK_FROM
  + deletion of empty file
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Tue Aug 15 2017 vpereira@suse.com
- fixed: bsc#1033244: john integration were broken
* Mon Mar  6 2017 vpereira@suse.com
- fixed: bsc#1021036: mute stderr on sysctl -a
* Sun Jul 24 2016 vpereira@suse.com
-  fixed bnc#985802: security monthly reports were broken
* Wed Oct  7 2015 vpereira@suse.com
- fixed bnc#942846: seccheck does not collect the same data in
  SLES 12 and SLES 11 sp3
- seccheck-3.0-fix-bashisms.patch and daily-mailer.patch were merged into upstream
* Mon Oct  5 2015 vpereira@suse.com
- use upstream version of code
* Mon Apr 27 2015 vpereira@suse.com
- added patch: emails-without-subject.patch to fix bnc#923688
* Tue Feb  3 2015 vpereira@suse.com
- bnc#914656: fixed function guessable_password_email definition
* Wed Dec 17 2014 Led <ledest@gmail.com>
- fix bashisms in scripts
- fix chebang of autologout.sh script than contains bash-specific
  constructions
- add patches:
  * seccheck-3.0-fix-bashisms.patch
* Tue Dec 16 2014 vpereira@suse.com
- daily-mailer.patch: applied patch suggested in bnc#904544
* Wed Sep  3 2014 vpereira@suse.com
- refactoring: each security test, has its own helper
- ran spec-clean
* Thu Aug 14 2014 vpereira@suse.com
- New version 3.0
- refactored codebase
- added new security tests
- moved the upstream to https://github.com/vpereira/seccheck
- Upstreamed patches:
  seccheck-2.0.diff
  seccheck-2.0-misc.patch
  seccheck-2.0-nisfix.patch
  seccheck-2.0-grep.patch
  seccheck-2.0-sort.patch
  seccheck-2.0-newpromisccheck.patch
  seccheck-2.0-filesystems_added.patch
  seccheck-2.0_john-path.diff
  seccheck-2.0_withoutmedia-bug47024.diff
  seccheck-2.0_update-datafiles-regexfix-bug51004.diff
  seccheck-2.0_fix-ls-output-local.diff
  seccheck-2.0_find_mount_arg.diff
  seccheck-2.0_find_with_dev.diff
  seccheck-2.0_dont_run_xarg_on_empty_input.diff
  seccheck-2.0-john.patch
  seccheck-2.0-website.patch
  seccheck-2.0_new_rpm_output_handle_more_filesystems_bnc746042.diff
  seccheck-2.0_daily_uid_bnc769770.diff
  seccheck-2.0-autologout.patch
* Wed Feb 19 2014 abergmann@suse.com
- Disable autologout as default (bnc#864534).
  (seccheck-2.0-autologout.patch)
* Fri Feb 14 2014 abergmann@suse.com
- Extended autologout functionality in seccheck-2.0-autologout.patch
  with SSH. See autologout.conf file for configuration details.
- Fixed issue if no user is logged on in seccheck-2.0-autologout.patch.
* Thu Feb 13 2014 abergmann@suse.com
- Added new autologout functionality. (FATE#312303)
  (added seccheck-2.0-autologout.patch)
* Wed Jul  4 2012 thomas@suse.com
- fixed bnc#769770 to improve reporting of account names
  with equal UIDs.
- change tmp fie handling and removed obsolete code
* Thu May 31 2012 thomas@suse.com
- bnc#746042 handle new "rpm -Va" output for md5 sums and don't
  limit the mount point detection to special filesystems
* Thu Feb  9 2012 thomas@suse.com
- fixed typo in seccheck-2.0_dont_run_xarg_on_empty_input.diff
  bnc#741737
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Tue Sep 22 2009 thomas@novell.com
- fixed patch seccheck-2.0_dont_run_xarg_on_empty_input.diff
  (bnc#540017)
* Wed Jan 14 2009 thomas@suse.de
- changed compression from gz to bz2
* Wed Jan 14 2009 thomas@suse.de
- improved patch seccheck-2.0-john.patch (bnc#465939)
* Sun Feb 11 2007 ro@suse.de
- fix build as non-root
* Wed Oct 11 2006 lrupp@suse.de
- point the user to the right place for security informations
* Wed Sep 13 2006 lrupp@suse.de
- find location of john automatically
* Mon Jul 24 2006 thomas@suse.de
- fixed bug #188579 (seccheck-2.0_dont_run_xarg_on_empty_input.diff)
* Mon Mar  6 2006 thomas@suse.de
- This update fixes the parameters for the 'find' command.
  (bug #154639)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 11 2006 thomas@suse.de
- removed seccheck-2.0_john-path.diff (bug #142053)
* Mon Aug  8 2005 thomas@suse.de
- fixed ls' time output regarding differnt locale settings
  bug #51004
* Wed Jul 27 2005 thomas@suse.de
- changed path to john to reflect new john packaging
- fixed some regex' (bug #51004)
- try to keep data files uptodate (bug #51004)
- avoid looking into /media directory (bug #47024)
* Mon Sep  6 2004 thomas@suse.de
- added patch to support more filesystems (Bug #44719)
* Tue Sep 30 2003 thomas@suse.de
- added new promisc mode check
* Tue Sep  2 2003 kukuk@suse.de
- Add sysconfig metadata [Bug #28935]
* Sun Aug  3 2003 poeml@suse.de
- sort was using obsolete syntax +1, replaced by -k2 [#28429]
* Fri Jun  6 2003 okir@suse.de
- grep -C was using obsolete syntax [#27258]
* Fri Feb 21 2003 mmj@suse.de
- Add sysconfig metadata [#22684]
* Wed Feb  5 2003 okir@suse.de
- do not complain about +joedoe NIS accounts (previously,
  we just ignored + and -) (#23146)
* Mon Nov 18 2002 okir@suse.de
- removed residual rc.config references
- START_SECCHECK now really works
- cleaned up the general blurb included in the mail messages
- daily sec check would incorrectly flag random home directories
  and dot files as owned by another user/group (#20720)
- use long-iso format in ls output (#21863)
- corrected spelling of sysconfig variable
  (SECCH*C*K_USER -> SECCHK_USER) (#15866, 16623)
- avoid different seccheck scripts from stepping on each others'
  toes when using a local copy of /etc/passwd (#16810)
- Stop warning about + and - lines in /etc/{shadow,passwd} (#21496)
- Allow user/group names of up to 32 characters (#21496 too)
* Mon Nov 11 2002 kukuk@suse.de
- Use sysconfig/seccheck, not rc.config
* Wed Jul 31 2002 ro@suse.de
- move to sysconfig, use prereq
* Fri Jul 13 2001 garloff@suse.de
- Added START_SECCHK variable to control whether the script will
  be run by cron. (see discussion @ bugzilla #5413).
  START_SECCHK defaults to "yes".
- Update to seccheck-2.0:
  * fixed an egrep bug - which was reported looooong time ago :-(
  * workarounds for Redhat ... they should update the mktempa and
    provide pidof ... duh ... (thanks to weutzing@exozet.com)
- Update to seccheck-1.9:
  * finally fixed the output of the weekly changes to prevent
    unnecessary lines
  * Added small fix to prevent "undisclosed receipent" msg in
    mailers
* Tue May  8 2001 garloff@suse.de
- Update to seccheck-1.8:
  * rewrote the mail header message for the change reports
  * added LICENCE (GPLv2) - required by SuSE policy
- Update to seccheck-1.7:
  * fixed a check for /etc/shadow password field contents
* Tue Apr 24 2001 garloff@suse.de
- Move it back to cron.d/seccheck. Otherwise users who use their
  machine only occasionally would see a significant performance
  hit.
* Wed Feb 21 2001 garloff@suse.de
- Start seccheck via cron.daily,weekly,monthly instead of
  cron.d/seccheck. The latter does not work, if the computer is not
  running at the specified time. (Bugzilla #5413, Ivory@SerNet.de)
* Tue Jan  9 2001 garloff@suse.de
- Add SECCHK_USER to /etc/rc.config (fillup-template), bug #5349
- Remove double sourcing of /etc/rc.config from security-control.sh
  script.
* Tue Dec 19 2000 garloff@suse.de
- Oops: Used %%{_tmpdir} instead of %%{_tmppath} in BuildRoot:
* Tue Dec 19 2000 garloff@suse.de
- seccheck-1.6:
  * Fix some DoS possibilities
  * Exlcude for NFS/cdrom was missing at one place in weekly
  * closed a hole against possibility of a backdoor trying
    to hide from lsof output
* Fri Sep 29 2000 garloff@suse.de
- seccheck-1.4: lsof fix and other minor fixes.
* Tue Jul 25 2000 garloff@suse.de
- egrep check for \\+ sign was missing the quoting \\ (#3461)
* Sun Jul  9 2000 garloff@suse.de
- Report version number properly (was erroneously set to 1.2)
* Fri Jun 30 2000 garloff@suse.de
- Update to version 1.3:
  * checkneverlogin
  * reiserfs support (suid/writable)
  * better output routines
  * some checks added
- Use BuildRoot.
* Tue Feb 15 2000 garloff@suse.de
- Version 0.9. Use install in spec-file instead of crufty
  cp/mkdir, chown, chmod sequences.
* Tue Oct 19 1999 bs@suse.de
- changed from /etc/cron.daily to /etc/cron.d with hardcoded starting times.
* Fri Oct  1 1999 bs@suse.de
- new version 0.8
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Apr 13 1999 bs@suse.de
- set version properly
* Tue Mar 30 1999 ro@suse.de
- new package
